@@ -1,4 +1,4 @@
-/* @(#) $Id: xwd.h 266 2015-07-04 21:39:04Z leres $ (XSE) */
+/* @(#) $Id: xwd.h 287 2017-01-21 19:15:36Z leres $ (XSE) */
 #ifndef xwd_h
 #define xwd_h
 
@@ -24,6 +24,6 @@ struct xwdheader {
 #define XWD_VX10 6
 #define XWD_VX11 7
 
-int parsexwd(const char *, int *, int *);
+int parsexwd(const char *, int *, int *, struct timespec *);
 int bs32(int);
 #endif
